@@ -18,7 +18,10 @@ use Mojo::DOM;
 
 use Mojolicious::Plugin::Vparam::Address;
 
-our $VERSION = '1.16';
+our $VERSION    = '1.17';
+
+# Shift for convert ASCII char position to simple sequence 0,1,2...9,A,B,C,,,
+our $CHAR_SHIFT = ord('A') - 10;
 
 =encoding utf-8
 
@@ -42,6 +45,10 @@ Many predefined types
 
 =item *
 
+Shortcats for the most common uses
+
+=item *
+
 Filters complementary types
 
 =item *
@@ -787,7 +794,7 @@ sub _check_isin($) {
     return 'Wrong format'           unless $_[0] =~ m{^[A-Z0-9]+$};
 
     my $str = $_[0];
-    s{([A-Z])}{(unpack('C*',$1)-55)}eg for $str;
+    s{([A-Z])}{(ord($1)-$CHAR_SHIFT)}eg for $str;
 
     my $crc = 0;
     my @str = reverse split '', $str;
@@ -898,11 +905,13 @@ After the application of the type used filters.
 
 Force value will array. Default: false.
 
-You can force values will arrays by B<@> prefix or B<array[...]>.
+You can force values will arrays by B<@> prefix or case insensive B<array[...]>.
 
-    # Arrays
+    # Arrays shortcut syntax
     $param1 = $self->vparam(array1 => '@int');
     $param2 = $self->vparam(array2 => 'array[int]');
+
+    # Array attribute syntax
     $param3 = $self->vparam(array3 => 'int', array => 1);
 
     # The array will come if more than one value incoming
@@ -917,7 +926,7 @@ Then true and value is not passed validation don`t set verrors.
 
     # Simple vparam
     # myparam is undef but no error.
-    $param6 = $self->vparam(myparam => 'int', optional => 1);
+    $param1 = $self->vparam(param1 => 'int', optional => 1);
 
     # Set one in vparams
     %params = $self->vparams(
@@ -931,6 +940,13 @@ Then true and value is not passed validation don`t set verrors.
         param2      => 'str',
     );
 
+    # Shortcut optional syntax
+    $param2 = $self->vparam(param2 => '?int');
+    $param3 = $self->vparam(param3 => 'maybe[int]');
+
+    # Shortcut required syntax
+    $param4 = $self->vparam(param4 => '!int');
+
 =head2 skip
 
 So as not to smear the validation code you can use the I<skip> parameter
@@ -1645,14 +1661,29 @@ sub register {
             # Apply type
             if( defined( my $type = $attr{type} ) ) {
 
-                # Set array flag if type have match for array
-                if( $type =~ m{^@} ) {
-                    s{^@}{} for $type;
-                    $attr{array} = 1;
+                # Optional shortcat
+                if( my ($realtype) = $type =~ m{\?(.*?)$} ) {
+                    $type           = $realtype;
+                    $attr{optional} = 1;
                 }
-                if( $type =~ m{^array\[(.*?)\]$} ) {
-                    s{^array\[(.*?)\]$}{$1} for $type;
-                    $attr{array} = 1;
+                if( my ($realtype) = $type =~ m{maybe\[(.*?)\]$}i ) {
+                    $type           = $realtype;
+                    $attr{optional} = 1;
+                }
+                # Required shortcat
+                if( my ($realtype) = $type =~ m{\!(.*?)$} ) {
+                    $type           = $realtype;
+                    $attr{optional} = 0;
+                }
+
+                # Array shortcat
+                if( my ($realtype) = $type =~ m{@(.*)$} ) {
+                    $type           = $realtype;
+                    $attr{array}    = 1;
+                }
+                if( my ($realtype) = $type =~ m{array\[(.*?)\]$}i ) {
+                    $type           = $realtype;
+                    $attr{array}    = 1;
                 }
 
                 if( exists $conf->{types}{ $type } ) {
